# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.post_data_retrieval_operation import PostDataRetrievalOperation

class TestPostDataRetrievalOperation(unittest.TestCase):
    """PostDataRetrievalOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PostDataRetrievalOperation:
        """Test PostDataRetrievalOperation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PostDataRetrievalOperation`
        """
        model = PostDataRetrievalOperation()
        if include_optional:
            return PostDataRetrievalOperation(
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                data_retrieval_filters = [
                    arthur_client.api_bindings.models.data_result_filter.DataResultFilter(
                        field_name = '', 
                        op = 'greater_than', 
                        value = null, )
                    ],
                pagination_options = arthur_client.api_bindings.models.connector_pagination_options.ConnectorPaginationOptions(
                    page = 1.0, 
                    page_size = 1.0, )
            )
        else:
            return PostDataRetrievalOperation(
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testPostDataRetrievalOperation(self):
        """Test PostDataRetrievalOperation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
